@@ -1,6 +1,7 @@
 import unittest
 from contextlib import nullcontext
 from datetime import datetime, timedelta, timezone
+from typing import Optional
 from unittest.mock import MagicMock, Mock, call, patch
 
 import pytest
@@ -592,9 +593,10 @@ class TestTwitchHLSMultivariantResponse:
         requests_mock.get("mock://multivariant", **getattr(request, "param", {}))
         return Twitch(session, "https://twitch.tv/channelname")
 
-    @pytest.mark.parametrize(("plugin", "raises", "streams", "log"), [
+    @pytest.mark.parametrize(("plugin", "streamid", "raises", "streams", "log"), [
         pytest.param(
             {"text": "#EXTM3U\n"},
+            "123",
             nullcontext(),
             {},
             [],
@@ -602,11 +604,28 @@ class TestTwitchHLSMultivariantResponse:
         ),
         pytest.param(
             {"text": "Not an HLS playlist"},
+            "123",
             pytest.raises(PluginError),
             {},
             [],
             id="invalid HLS playlist",
         ),
+        pytest.param(
+            {
+                "status_code": 404,
+                "json": [{
+                    "url": "mock://multivariant",
+                    "error": "twirp error not_found: transcode does not exist",
+                    "error_code": "transcode_does_not_exist",
+                    "type": "error",
+                }],
+            },
+            None,
+            nullcontext(),
+            None,
+            [],
+            id="offline",
+        ),
         pytest.param(
             {
                 "status_code": 403,
@@ -617,6 +636,7 @@ class TestTwitchHLSMultivariantResponse:
                     "type": "error",
                 }],
             },
+            "123",
             nullcontext(),
             None,
             [("streamlink.plugins.twitch", "error", "Content Restricted In Region")],
@@ -627,14 +647,25 @@ class TestTwitchHLSMultivariantResponse:
                 "status_code": 404,
                 "text": "Not found",
             },
+            "123",
             nullcontext(),
             None,
-            [("streamlink.plugins.twitch", "error", "Could not access HLS playlist")],
+            [],
             id="non-json error response",
         ),
     ], indirect=["plugin"])
-    def test_multivariant_response(self, caplog: pytest.LogCaptureFixture, plugin: Twitch, raises, streams, log):
+    def test_multivariant_response(
+        self,
+        monkeypatch: pytest.MonkeyPatch,
+        caplog: pytest.LogCaptureFixture,
+        plugin: Twitch,
+        streamid: Optional[str],
+        raises: nullcontext,
+        streams: Optional[dict],
+        log: list,
+    ):
         caplog.set_level("error", "streamlink.plugins.twitch")
+        monkeypatch.setattr(plugin, "get_id", Mock(return_value=streamid))
         with raises:
             assert plugin._get_hls_streams("mock://multivariant", []) == streams
         assert [(record.name, record.levelname, record.message) for record in caplog.records] == log
@@ -834,63 +865,3 @@ class TestTwitchMetadata:
         assert author is None
         assert category is None
         assert title is None
-
-
-@pytest.mark.parametrize(("stream_type", "offline", "disable", "expected", "logs"), [
-    pytest.param(
-        "live",
-        False,
-        True,
-        False,
-        [],
-        id="disable live",
-    ),
-    pytest.param(
-        "rerun",
-        False,
-        True,
-        True,
-        [("streamlink.plugins.twitch", "info", "Reruns were disabled by command line option")],
-        id="disable not live",
-    ),
-    pytest.param(
-        "live",
-        True,
-        True,
-        False,
-        [],
-        id="disable offline",
-    ),
-    pytest.param(
-        "rerun",
-        True,
-        False,
-        False,
-        [],
-        id="enable",
-    ),
-])
-def test_reruns(
-    monkeypatch: pytest.MonkeyPatch,
-    caplog: pytest.LogCaptureFixture,
-    session: Streamlink,
-    stream_type: str,
-    offline: bool,
-    disable: bool,
-    expected: bool,
-    logs: list,
-):
-    caplog.set_level(1, "streamlink")
-    mock_stream_metadata = Mock(return_value=None if offline else {"type": stream_type})
-    monkeypatch.setattr("streamlink.plugins.twitch.TwitchAPI.stream_metadata", mock_stream_metadata)
-
-    # noinspection PyTypeChecker
-    plugin: Twitch = Twitch(session, "https://www.twitch.tv/foo")
-    try:
-        plugin.options.set("disable-reruns", disable)
-        result = plugin._check_for_rerun()
-    finally:
-        plugin.options.clear()
-
-    assert result is expected
-    assert [(record.name, record.levelname, record.message) for record in caplog.records] == logs
